@@ -2,7 +2,7 @@ import click
 from pprint import pprint
 from pathlib import Path
 from subprocess import run
-from importlib.metadata import version
+from importlib.metadata import metadata
 import yaml
 import toml
 import os
@@ -51,7 +51,8 @@ def cli():
 @cli.command()
 def version():
     "Print MWC version"
-    click.echo(address("MWC " + version('making-with-code-cli'), preformatted=True))
+    version = metadata('making-with-code-cli')['version']
+    click.echo(address("MWC " + version, preformatted=True))
 
 @cli.command()
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
